@@ -776,7 +776,13 @@ class CfnRecordingConfiguration(
             tags=[CfnTag(
                 key="key",
                 value="value"
-            )]
+            )],
+            thumbnail_configuration=ivs.CfnRecordingConfiguration.ThumbnailConfigurationProperty(
+                recording_mode="recordingMode",
+        
+                # the properties below are optional
+                target_interval_seconds=123
+            )
         )
     '''
 
@@ -788,6 +794,7 @@ class CfnRecordingConfiguration(
         destination_configuration: typing.Union[aws_cdk.core.IResolvable, "CfnRecordingConfiguration.DestinationConfigurationProperty"],
         name: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.Sequence[aws_cdk.core.CfnTag]] = None,
+        thumbnail_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnRecordingConfiguration.ThumbnailConfigurationProperty"]] = None,
     ) -> None:
         '''Create a new ``AWS::IVS::RecordingConfiguration``.
 
@@ -796,9 +803,13 @@ class CfnRecordingConfiguration(
         :param destination_configuration: A destination configuration contains information about where recorded video will be stored. See the `DestinationConfiguration <https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivs-recordingconfiguration-destinationconfiguration.html>`_ property type for more information.
         :param name: Recording-configuration name. The value does not need to be unique.
         :param tags: An array of key-value pairs to apply to this resource. For more information, see `Tag <https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html>`_ .
+        :param thumbnail_configuration: A thumbnail configuration enables/disables the recording of thumbnails for a live session and controls the interval at which thumbnails are generated for the live session. See the `ThumbnailConfiguration <https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivs-recordingconfiguration-thunbnailconfiguration.html>`_ property type for more information.
         '''
         props = CfnRecordingConfigurationProps(
-            destination_configuration=destination_configuration, name=name, tags=tags
+            destination_configuration=destination_configuration,
+            name=name,
+            tags=tags,
+            thumbnail_configuration=thumbnail_configuration,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -900,6 +911,26 @@ class CfnRecordingConfiguration(
     def name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "name", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="thumbnailConfiguration")
+    def thumbnail_configuration(
+        self,
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnRecordingConfiguration.ThumbnailConfigurationProperty"]]:
+        '''A thumbnail configuration enables/disables the recording of thumbnails for a live session and controls the interval at which thumbnails are generated for the live session.
+
+        See the `ThumbnailConfiguration <https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivs-recordingconfiguration-thunbnailconfiguration.html>`_ property type for more information.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ivs-recordingconfiguration.html#cfn-ivs-recordingconfiguration-thumbnailconfiguration
+        '''
+        return typing.cast(typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnRecordingConfiguration.ThumbnailConfigurationProperty"]], jsii.get(self, "thumbnailConfiguration"))
+
+    @thumbnail_configuration.setter
+    def thumbnail_configuration(
+        self,
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnRecordingConfiguration.ThumbnailConfigurationProperty"]],
+    ) -> None:
+        jsii.set(self, "thumbnailConfiguration", value)
+
     @jsii.data_type(
         jsii_type="@aws-cdk/aws-ivs.CfnRecordingConfiguration.DestinationConfigurationProperty",
         jsii_struct_bases=[],
@@ -1010,6 +1041,91 @@ class CfnRecordingConfiguration(
                 k + "=" + repr(v) for k, v in self._values.items()
             )
 
+    @jsii.data_type(
+        jsii_type="@aws-cdk/aws-ivs.CfnRecordingConfiguration.ThumbnailConfigurationProperty",
+        jsii_struct_bases=[],
+        name_mapping={
+            "recording_mode": "recordingMode",
+            "target_interval_seconds": "targetIntervalSeconds",
+        },
+    )
+    class ThumbnailConfigurationProperty:
+        def __init__(
+            self,
+            *,
+            recording_mode: builtins.str,
+            target_interval_seconds: typing.Optional[jsii.Number] = None,
+        ) -> None:
+            '''The ThumbnailConfiguration property type describes a configuration of thumbnails for recorded video.
+
+            :param recording_mode: Thumbnail recording mode. Valid values:. - ``DISABLED`` : Use DISABLED to disable the generation of thumbnails for recorded video. - ``INTERVAL`` : Use INTERVAL to enable the generation of thumbnails for recorded video at a time interval controlled by the `TargetIntervalSeconds <https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivs-recordingconfiguration-thumbnailconfiguration.html#cfn-ivs-recordingconfiguration-thumbnailconfiguration-targetintervalseconds>`_ property. *Default* : ``INTERVAL``
+            :param target_interval_seconds: The targeted thumbnail-generation interval in seconds. This is configurable (and required) only if `RecordingMode <https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivs-recordingconfiguration-thumbnailconfiguration.html#cfn-ivs-recordingconfiguration-thumbnailconfiguration-recordingmode>`_ is ``INTERVAL`` . .. epigraph:: Setting a value for ``TargetIntervalSeconds`` does not guarantee that thumbnails are generated at the specified interval. For thumbnails to be generated at the ``TargetIntervalSeconds`` interval, the ``IDR/Keyframe`` value for the input video must be less than the ``TargetIntervalSeconds`` value. See `Amazon IVS Streaming Configuration <https://docs.aws.amazon.com/ivs/latest/userguide/streaming-config.html>`_ for information on setting ``IDR/Keyframe`` to the recommended value in video-encoder settings. *Default* : 60 *Valid Range* : Minumum value of 5. Maximum value of 60.
+
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivs-recordingconfiguration-thumbnailconfiguration.html
+            :exampleMetadata: fixture=_generated
+
+            Example::
+
+                # The code below shows an example of how to instantiate this type.
+                # The values are placeholders you should change.
+                import aws_cdk.aws_ivs as ivs
+                
+                thumbnail_configuration_property = ivs.CfnRecordingConfiguration.ThumbnailConfigurationProperty(
+                    recording_mode="recordingMode",
+                
+                    # the properties below are optional
+                    target_interval_seconds=123
+                )
+            '''
+            self._values: typing.Dict[str, typing.Any] = {
+                "recording_mode": recording_mode,
+            }
+            if target_interval_seconds is not None:
+                self._values["target_interval_seconds"] = target_interval_seconds
+
+        @builtins.property
+        def recording_mode(self) -> builtins.str:
+            '''Thumbnail recording mode. Valid values:.
+
+            - ``DISABLED`` : Use DISABLED to disable the generation of thumbnails for recorded video.
+            - ``INTERVAL`` : Use INTERVAL to enable the generation of thumbnails for recorded video at a time interval controlled by the `TargetIntervalSeconds <https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivs-recordingconfiguration-thumbnailconfiguration.html#cfn-ivs-recordingconfiguration-thumbnailconfiguration-targetintervalseconds>`_ property.
+
+            *Default* : ``INTERVAL``
+
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivs-recordingconfiguration-thumbnailconfiguration.html#cfn-ivs-recordingconfiguration-thumbnailconfiguration-recordingmode
+            '''
+            result = self._values.get("recording_mode")
+            assert result is not None, "Required property 'recording_mode' is missing"
+            return typing.cast(builtins.str, result)
+
+        @builtins.property
+        def target_interval_seconds(self) -> typing.Optional[jsii.Number]:
+            '''The targeted thumbnail-generation interval in seconds. This is configurable (and required) only if `RecordingMode <https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivs-recordingconfiguration-thumbnailconfiguration.html#cfn-ivs-recordingconfiguration-thumbnailconfiguration-recordingmode>`_ is ``INTERVAL`` .
+
+            .. epigraph::
+
+               Setting a value for ``TargetIntervalSeconds`` does not guarantee that thumbnails are generated at the specified interval. For thumbnails to be generated at the ``TargetIntervalSeconds`` interval, the ``IDR/Keyframe`` value for the input video must be less than the ``TargetIntervalSeconds`` value. See `Amazon IVS Streaming Configuration <https://docs.aws.amazon.com/ivs/latest/userguide/streaming-config.html>`_ for information on setting ``IDR/Keyframe`` to the recommended value in video-encoder settings.
+
+            *Default* : 60
+
+            *Valid Range* : Minumum value of 5. Maximum value of 60.
+
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivs-recordingconfiguration-thumbnailconfiguration.html#cfn-ivs-recordingconfiguration-thumbnailconfiguration-targetintervalseconds
+            '''
+            result = self._values.get("target_interval_seconds")
+            return typing.cast(typing.Optional[jsii.Number], result)
+
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return "ThumbnailConfigurationProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
+
 
 @jsii.data_type(
     jsii_type="@aws-cdk/aws-ivs.CfnRecordingConfigurationProps",
@@ -1018,6 +1134,7 @@ class CfnRecordingConfiguration(
         "destination_configuration": "destinationConfiguration",
         "name": "name",
         "tags": "tags",
+        "thumbnail_configuration": "thumbnailConfiguration",
     },
 )
 class CfnRecordingConfigurationProps:
@@ -1027,12 +1144,14 @@ class CfnRecordingConfigurationProps:
         destination_configuration: typing.Union[aws_cdk.core.IResolvable, CfnRecordingConfiguration.DestinationConfigurationProperty],
         name: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.Sequence[aws_cdk.core.CfnTag]] = None,
+        thumbnail_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, CfnRecordingConfiguration.ThumbnailConfigurationProperty]] = None,
     ) -> None:
         '''Properties for defining a ``CfnRecordingConfiguration``.
 
         :param destination_configuration: A destination configuration contains information about where recorded video will be stored. See the `DestinationConfiguration <https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivs-recordingconfiguration-destinationconfiguration.html>`_ property type for more information.
         :param name: Recording-configuration name. The value does not need to be unique.
         :param tags: An array of key-value pairs to apply to this resource. For more information, see `Tag <https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html>`_ .
+        :param thumbnail_configuration: A thumbnail configuration enables/disables the recording of thumbnails for a live session and controls the interval at which thumbnails are generated for the live session. See the `ThumbnailConfiguration <https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivs-recordingconfiguration-thunbnailconfiguration.html>`_ property type for more information.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ivs-recordingconfiguration.html
         :exampleMetadata: fixture=_generated
@@ -1055,7 +1174,13 @@ class CfnRecordingConfigurationProps:
                 tags=[CfnTag(
                     key="key",
                     value="value"
-                )]
+                )],
+                thumbnail_configuration=ivs.CfnRecordingConfiguration.ThumbnailConfigurationProperty(
+                    recording_mode="recordingMode",
+            
+                    # the properties below are optional
+                    target_interval_seconds=123
+                )
             )
         '''
         self._values: typing.Dict[str, typing.Any] = {
@@ -1065,6 +1190,8 @@ class CfnRecordingConfigurationProps:
             self._values["name"] = name
         if tags is not None:
             self._values["tags"] = tags
+        if thumbnail_configuration is not None:
+            self._values["thumbnail_configuration"] = thumbnail_configuration
 
     @builtins.property
     def destination_configuration(
@@ -1102,6 +1229,19 @@ class CfnRecordingConfigurationProps:
         result = self._values.get("tags")
         return typing.cast(typing.Optional[typing.List[aws_cdk.core.CfnTag]], result)
 
+    @builtins.property
+    def thumbnail_configuration(
+        self,
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, CfnRecordingConfiguration.ThumbnailConfigurationProperty]]:
+        '''A thumbnail configuration enables/disables the recording of thumbnails for a live session and controls the interval at which thumbnails are generated for the live session.
+
+        See the `ThumbnailConfiguration <https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivs-recordingconfiguration-thunbnailconfiguration.html>`_ property type for more information.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ivs-recordingconfiguration.html#cfn-ivs-recordingconfiguration-thumbnailconfiguration
+        '''
+        result = self._values.get("thumbnail_configuration")
+        return typing.cast(typing.Optional[typing.Union[aws_cdk.core.IResolvable, CfnRecordingConfiguration.ThumbnailConfigurationProperty]], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
